==> haskell-hls-retrie-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-JPtRBzZZ27uB8gq6Q2BEfm
key:                  hls-retrie-plugin-2.1.0.0-JPtRBzZZ27uB8gq6Q2BEfm
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3b221fd08991863ecacb7a44e84562fe
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-JPtRBzZZ27uB8gq6Q2BEfm
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    hls-refactor-plugin-2.1.0.0-3a2DGLmo4jC4uYcr4QLr53
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1
    retrie-1.2.3-3BFf1hlshVm6m2JkJ2mw4i
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI stm-2.5.1.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-retrie-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-retrie-plugin-2.1.0.0-7iYIe56Knz1HOEkD1dzLDs
key:                  hls-retrie-plugin-2.1.0.0-7iYIe56Knz1HOEkD1dzLDs
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2028ec68cec50f9fb63ff2fc3db9f117
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-retrie-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.1.0.0-7iYIe56Knz1HOEkD1dzLDs
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-IkudFHstV64EKMSGT8IWWb ghc-9.6.6
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    hls-refactor-plugin-2.1.0.0-IMWSL03tp3QLVnlPUttUmn
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3 mtl-2.3.1
    retrie-1.2.3-3ST87g1en3RAjYTKpoZXal
    safe-exceptions-0.1.7.4-77vNmGqKu2OFQzf0vTZZHI stm-2.5.1.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
